==> fulibScenarios-0.3.1-sources.jar: org/fulib/scenarios/ast/decl/AttributeDecl.java <==
package org.fulib.scenarios.ast.decl;

import org.fulib.scenarios.ast.Node;


public interface AttributeDecl extends Decl
{
	// =============== Static Methods ===============
	static AttributeDecl of(ClassDecl owner, String name, String type) { return new Impl(owner, name, type); }
	// =============== Properties ===============
	ClassDecl getOwner();
	void setOwner(ClassDecl owner);
	String getName();
	void setName(String name);
	String getType();
	void setType(String type);

	// =============== Methods ===============
	<P, R> R accept(AttributeDecl.Visitor<P, R> visitor, P par);
	// =============== Classes ===============
	class Impl implements AttributeDecl
	{
		// =============== Fields ===============
		private ClassDecl owner;
		private String name;
		private String type;

		// =============== Constructors ===============
		public Impl() {}
		public Impl(ClassDecl owner, String name, String type)
		{
			this.owner = owner;
			this.name = name;
			this.type = type;
		}

		// =============== Properties ===============
		@Override public ClassDecl getOwner() { return this.owner; }
		@Override public void setOwner(ClassDecl owner) { this.owner = owner; }
		@Override public String getName() { return this.name; }
		@Override public void setName(String name) { this.name = name; }
		@Override public String getType() { return this.type; }
		@Override public void setType(String type) { this.type = type; }

		// =============== Methods ===============
		@Override public <P, R> R accept(AttributeDecl.Visitor<P, R> visitor, P par) { return visitor.visit(this, par); }
		@Override public <P, R> R accept(Decl.Visitor<P, R> visitor, P par) { return visitor.visit(this, par); }
		@Override public <P, R> R accept(Node.Visitor<P, R> visitor, P par) { return visitor.visit(this, par); }

	}
	interface Visitor<P, R>
	{
		// =============== Methods ===============
		R visit(AttributeDecl attributeDecl, P par);
	}
}

==> fulibScenarios-0.4.0-sources.jar: org/fulib/scenarios/ast/decl/AttributeDecl.java <==
package org.fulib.scenarios.ast.decl;

import org.fulib.scenarios.ast.Node;
import org.fulib.scenarios.ast.type.Type;


public interface AttributeDecl extends Decl
{
	// =============== Static Methods ===============
	static AttributeDecl of(ClassDecl owner, String name, Type type) { return new Impl(owner, name, type); }
	// =============== Properties ===============
	ClassDecl getOwner();
	void setOwner(ClassDecl owner);
	String getName();
	void setName(String name);
	Type getType();
	void setType(Type type);

	// =============== Methods ===============
	<P, R> R accept(AttributeDecl.Visitor<P, R> visitor, P par);
	// =============== Classes ===============
	class Impl implements AttributeDecl
	{
		// =============== Fields ===============
		private ClassDecl owner;
		private String name;
		private Type type;

		// =============== Constructors ===============
		public Impl() {}
		public Impl(ClassDecl owner, String name, Type type)
		{
			this.owner = owner;
			this.name = name;
			this.type = type;
		}

		// =============== Properties ===============
		@Override public ClassDecl getOwner() { return this.owner; }
		@Override public void setOwner(ClassDecl owner) { this.owner = owner; }
		@Override public String getName() { return this.name; }
		@Override public void setName(String name) { this.name = name; }
		@Override public Type getType() { return this.type; }
		@Override public void setType(Type type) { this.type = type; }

		// =============== Methods ===============
		@Override public <P, R> R accept(AttributeDecl.Visitor<P, R> visitor, P par) { return visitor.visit(this, par); }
		@Override public <P, R> R accept(Decl.Visitor<P, R> visitor, P par) { return visitor.visit(this, par); }
		@Override public <P, R> R accept(Node.Visitor<P, R> visitor, P par) { return visitor.visit(this, par); }

	}
	interface Visitor<P, R>
	{
		// =============== Methods ===============
		R visit(AttributeDecl attributeDecl, P par);
	}
}
